@@ -24,6 +24,7 @@ LOG = logging.getLogger('feedhandler')
 class Bitflyer(Feed):
     id = BITFLYER
     symbol_endpoint = endpoints = ['https://api.bitflyer.com/v1/getmarkets/eu', 'https://api.bitflyer.com/v1/getmarkets/usa', 'https://api.bitflyer.com/v1/getmarkets']
+    websocket_endpoint = 'wss://ws.lightstream.bitflyer.com/json-rpc'
     websocket_channels = {
         L2_BOOK: 'lightning_board_{}',
         TRADES: 'lightning_executions_{}',
@@ -52,9 +53,6 @@ class Bitflyer(Feed):
                 info['instrument_type'][s.normalized] = stype
         return ret, info
 
-    def __init__(self, **kwargs):
-        super().__init__('wss://ws.lightstream.bitflyer.com/json-rpc', **kwargs)
-
     def __reset(self):
         self._l2_book = {}
 
